@@ -40,7 +40,7 @@ describe 'ironic::drivers::drac' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts())
       end
-      it_configures 'ironic drac driver'
+      it_behaves_like 'ironic drac driver'
     end
   end
 
