@@ -33,7 +33,7 @@ describe 'ironic::pxe' do
       is_expected.to contain_file('/tftpboot/pxelinux.cfg').with(
         'owner'   => 'ironic',
         'group'   => 'ironic',
-        'require' => 'Package[ironic-common]',
+        'require' => 'Anchor[ironic::install::end]',
         'ensure'  => 'directory',
         'seltype' => 'tftpdir_t',
       )
@@ -64,7 +64,6 @@ describe 'ironic::pxe' do
        'server'      => '/usr/sbin/in.tftpd',
        'socket_type' => 'dgram',
        'cps'         => '100 2',
-       'flags'       => 'IPv4',
        'per_source'  => '11',
        'wait'        => 'yes',
        'subscribe'   => 'Anchor[ironic::install::end]',
@@ -77,6 +76,7 @@ describe 'ironic::pxe' do
           :tftp_root => '/var/lib/tftpboot',
           :http_root => '/var/www/httpboot',
           :http_port => 3816,
+          :tftp_bind_host => '1.2.3.4',
         )
       end
 
@@ -104,7 +104,7 @@ describe 'ironic::pxe' do
         is_expected.to contain_file('/var/lib/tftpboot/undionly.kpxe').with(
           'owner'   => 'ironic',
           'group'   => 'ironic',
-          'require' => 'Package[ipxe]',
+          'require' => 'Anchor[ironic-inspector::install::end]',
           'seltype' => 'tftpdir_t',
           'ensure'  => 'present',
           'backup'  => false,
@@ -114,37 +114,44 @@ describe 'ironic::pxe' do
         is_expected.to contain_file('/var/lib/tftpboot/ipxe.efi').with(
           'owner'   => 'ironic',
           'group'   => 'ironic',
-          'require' => 'Package[ipxe]',
+          'require' => 'Anchor[ironic-inspector::install::end]',
           'seltype' => 'tftpdir_t',
           'ensure'  => 'present',
           'backup'  => false,
         )
       end
+      it 'should setup tftp xinetd service' do
+        is_expected.to contain_xinetd__service('tftp').with(
+         'bind' => '1.2.3.4',
+        )
+      end
+    end
+    context 'when excluding syslinux' do
+      before :each do
+        params.merge!(
+          :syslinux_path => false,
+        )
+      end
+      it 'should not contain package syslinux' do
+        is_expected.not_to contain_package('syslinux')
+      end
+      it 'should not contain tftpboot syslinux file' do
+        is_expected.not_to contain_file('/tftpboot/pxelinux.0')
+      end
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily               => 'Debian',
-        :operatingsystem        => 'Debian',
-        :operatingsystemrelease => '7.0'
-      })
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      it_behaves_like 'ironic pxe'
+
     end
-
-    it_configures 'ironic pxe'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily               => 'RedHat',
-        :operatingsystem        => 'CentOS',
-        :operatingsystemrelease => '7.2.1511'
-      })
-    end
-
-    it_configures 'ironic pxe'
   end
 
 end
